@@ -35,7 +35,7 @@ class Hydra(Collector):
         self.table_name = "unique_ips"
 
         try:
-            self.conn = sqlite3.connect(digital_hydrant.config.db_path)
+            self.conn = sqlite3.connect(digital_hydrant.config.db_path, timeout=10)
             self.cursor = self.conn.cursor()
         except Exception as err:
             self.logger.critical(f"Failed to connect to the database: {err}")
