@@ -30,7 +30,7 @@ class Nmap(Collector):
         self.table_name = "unique_ips"
 
         try:
-            self.conn = sqlite3.connect(db_path)
+            self.conn = sqlite3.connect(db_path, timeout=10)
             self.cursor = self.conn.cursor()
         except Exception as err:
             self.logger.critical(f"Failed to connect to the database: {err}")
