@@ -24,7 +24,7 @@ from digital_hydrant.collector_queue import CollectorQueue
 from digital_hydrant.ping import Ping
 from digital_hydrant.args import args
 from digital_hydrant.process_manager import ProcessManager
-from digital_hydrant.config import db_path, update_config, check_default_config
+from digital_hydrant.config import config, db_path, update_config, check_default_config
 from digital_hydrant.migration import migrate_db
 
 
@@ -67,6 +67,9 @@ def run():
         print("\ninit complete!")
         return
 
+    if config.get("api", "token", fallback="") == "":
+        sys.exit("ERROR: Missing API token\nPlease re-run `hydrant --init TOKEN`")
+
     if missing:
         sys.exit(
             "\nPlease install all required dependencies or use -f/--force to run without dependencies"
