@@ -13,7 +13,7 @@ def migrate_db():
         return int(path.split("_")[0].split("/")[1])
 
     try:
-        cursor = sqlite3.connect(db_path).cursor()
+        cursor = sqlite3.connect(db_path, timeout=10).cursor()
     except Exception as e:
         logger.critical(f"Failed to initialize database: {err}")
         exit(1)
