@@ -85,13 +85,6 @@ class ProcessManager:
                     }
                 )
 
-                if self.job_schedules[name] == "* * * * *" and (
-                    name not in self.last_retry or now() - self.last_retry[name] > 10
-                ):
-                    self.run_job_once(name)
-                    self.last_retry[name] = now()
-                    self.logger.info(f"Retrying {name}")
-
                 raise
 
         return wrapped
@@ -266,6 +259,21 @@ class ProcessManager:
                 ):
                     self.scheduler.cancel_job(self.jobs[name])
                     self.schedule(name, cron)
+                elif (
+                    enabled
+                    and scheduled
+                    and name in self.processes
+                    and not self.processes[name].is_alive()
+                    and self.processes[name].exitcode != 0
+                    and cron == "* * * * *"
+                    and (
+                        name not in self.last_retry
+                        or now() - self.last_retry[name] > 10
+                    )
+                ):
+                    self.run_job_once(name)
+                    self.last_retry[name] = now()
+                    self.logger.info(f"Retrying {name}")
 
                 if scheduled:
                     active.append(name)
