@@ -9,7 +9,7 @@ from digital_hydrant.config import db_path
 
 class TestServerDataProcessor(unittest.TestCase):
     def setUp(self):
-        self.conn = sqlite3.connect(db_path)
+        self.conn = sqlite3.connect(db_path, timeout=10)
         self.cursor = self.conn.cursor()
         self.cursor.execute(
             "CREATE TABLE IF NOT EXISTS unique_ips (id INTEGER PRIMARY KEY AUTOINCREMENT, ip TEXT UNIQUE, last_tested TIMESTAMP, last_nmap_scan TIMESTAMP, open_ports TEXT)"
